@@ -8,10 +8,27 @@
 #' @param x object containing resampled metrics.
 #' @param ... arguments to be passed to other methods.
 #' 
-#' @return ResamplesDiff class object that inherits from Resamples.
+#' @return \code{ModelMetricsDiff} class object that inherits from
+#' \code{ModelMetrics}.
 #' 
-#' @seealso \code{\link{plot}}, \code{\link{resample}}, \code{\link{Resamples}},
-#' \code{\link{summary}}, \code{\link{t.test}}
+#' @seealso \code{\link{modelmetrics}}, \code{\link{resample}},
+#' \code{\link{tune}}, \code{\link{plot}}, \code{\link{summary}},
+#' \code{\link{t.test}}
+#' 
+diff.ModelMetrics <- function(x, ...) {
+  if (length(dim(x)) <= 2) stop("more than one model needed to diff")
+  indices <- combn(dim(x)[3], 2)
+  indices1 <- indices[1,]
+  indices2 <- indices[2,]
+  xdiff <- x[, , indices1, drop = FALSE] - x[, , indices2, drop = FALSE]
+  model_names <- dimnames(x)[[3]]
+  dimnames(xdiff)[[3]] <-
+    paste(model_names[indices1], "-", model_names[indices2])
+  ModelMetricsDiff(xdiff, model_names = model_names)
+}
+
+
+#' @rdname diff-methods
 #' 
 #' @examples
 #' ## Survival response example
@@ -21,33 +38,24 @@
 #' fo <- Surv(time, status != 2) ~ sex + age + year + thickness + ulcer
 #' control <- CVControl()
 #' 
-#' gbmperf1 <- resample(fo, Melanoma, GBMModel(n.trees = 25), control)
-#' gbmperf2 <- resample(fo, Melanoma, GBMModel(n.trees = 50), control)
-#' gbmperf3 <- resample(fo, Melanoma, GBMModel(n.trees = 100), control)
+#' gbmres1 <- resample(fo, Melanoma, GBMModel(n.trees = 25), control)
+#' gbmres2 <- resample(fo, Melanoma, GBMModel(n.trees = 50), control)
+#' gbmres3 <- resample(fo, Melanoma, GBMModel(n.trees = 100), control)
 #' 
-#' perf <- Resamples(GBM1 = gbmperf1, GBM2 = gbmperf2, GBM3 = gbmperf3)
-#' perfdiff <- diff(perf)
+#' res <- Resamples(GBM1 = gbmres1, GBM2 = gbmres2, GBM3 = gbmres3)
+#' perfdiff <- diff(res)
 #' summary(perfdiff)
 #' plot(perfdiff)
 #' 
-diff.MLModelTune <- function(x, ...) {
-  diff(x@resamples)
+diff.Resamples <- function(x, ...) {
+  diff(modelmetrics(x))
 }
 
 
 #' @rdname diff-methods
 #' 
-diff.Resamples <- function(x, ...) {
-  if (length(dim(x)) <= 2) stop("more than one model needed to diff")
-  indices <- combn(dim(x)[3], 2)
-  indices1 <- indices[1,]
-  indices2 <- indices[2,]
-  xdiff <- x[, , indices1, drop = FALSE] - x[, , indices2, drop = FALSE]
-  model_names <- dimnames(x)[[3]]
-  dimnames(xdiff)[[3]] <-
-    paste(model_names[indices1], "-", model_names[indices2])
-  ResamplesDiff(xdiff, control = x@control, response = x@response,
-                strata = x@strata)
+diff.MLModelTune <- function(x, ...) {
+  diff(x@resamples)
 }
 
 
@@ -63,10 +71,10 @@ diff.Resamples <- function(x, ...) {
 #' implemented by \code{\link[stats]{p.adjust}}.
 #' @param ... arguments passed to other metrics.
 #' 
-#' @return ResamplesHTest class object that inherits from array.  p-values and
-#' mean differences are contained in the lower and upper triangular portions,
-#' respectively, of the first two dimensions.  Model pairs are contined in the
-#' third dimension.
+#' @return \code{HTestResamples} class object that inherits from \code{array}.
+#' p-values and mean differences are contained in the lower and upper triangular
+#' portions, respectively, of the first two dimensions.  Model pairs are
+#' contined in the third dimension.
 #' 
 #' @seealso \code{\link{diff}}
 #' 
@@ -77,22 +85,22 @@ diff.Resamples <- function(x, ...) {
 #' fo <- medv ~ .
 #' control <- CVControl()
 #' 
-#' gbmperf1 <- resample(fo, Boston, GBMModel(n.trees = 25), control)
-#' gbmperf2 <- resample(fo, Boston, GBMModel(n.trees = 50), control)
-#' gbmperf3 <- resample(fo, Boston, GBMModel(n.trees = 100), control)
+#' gbmres1 <- resample(fo, Boston, GBMModel(n.trees = 25), control)
+#' gbmres2 <- resample(fo, Boston, GBMModel(n.trees = 50), control)
+#' gbmres3 <- resample(fo, Boston, GBMModel(n.trees = 100), control)
 #' 
-#' perf <- Resamples(GBM1 = gbmperf1, GBM2 = gbmperf2, GBM3 = gbmperf3)
-#' perfdiff <- diff(perf)
+#' res <- Resamples(GBM1 = gbmres1, GBM2 = gbmres2, GBM3 = gbmres3)
+#' perfdiff <- diff(res)
 #' t.test(perfdiff)
 #' 
-t.test.ResamplesDiff <- function(x, adjust = "holm", ...)
+t.test.ModelMetricsDiff <- function(x, adjust = "holm", ...)
 {
   pvalues <- x %>%
     apply(c(3, 2), function(resample) t.test(resample)$p.value) %>%
     apply(2, p.adjust, method = adjust)
   meandiffs <- apply(x, c(3, 2), mean, na.rm = TRUE)
   
-  model_names <- levels(x@response$Model)
+  model_names <- x@model_names
   num_models <- length(model_names)
   results <- array(NA, dim = c(num_models, num_models, dim(x)[2]),
                    dimnames = list(model_names, model_names, dimnames(x)[[2]]))
@@ -101,5 +109,5 @@ t.test.ResamplesDiff <- function(x, adjust = "holm", ...)
   results <- aperm(results, perm = c(2, 1, 3))
   results[indices] <- pvalues
 
-  ResamplesHTest(results, adjust = adjust)
+  HTestResamples(results, adjust = adjust)
 }
