@@ -41,7 +41,7 @@ test_tune <- function() {
 test_that("model comparisons", {
   skip_if_not(TEST_MODEL_COMPARISONS)
   with_parallel({
-    expect_is(test_Resamples(), "ResamplesHTest")
-    expect_is(test_tune(), "ResamplesHTest")
+    expect_is(test_Resamples(), "HTestResamples")
+    expect_is(test_tune(), "HTestResamples")
   })
 })
